AdvancedMarkerController class

A MarkerController that wraps a gmaps.AdvancedMarkerElement object.

gmaps.AdvancedMarkerElement is a new class that is replacing gmaps.Marker.

Inheritance

Constructors

AdvancedMarkerController({required AdvancedMarkerElement marker, InfoWindow? infoWindow, bool consumeTapEvents = false, LatLngCallback? onDragStart, LatLngCallback? onDrag, LatLngCallback? onDragEnd, VoidCallback? onTap, ClusterManagerId? clusterManagerId})
Creates a AdvancedMarkerController, which wraps a gmaps.AdvancedMarkerElement object.

Properties

clusterManagerId → ClusterManagerId?
Returns ClusterManagerId if marker belongs to cluster.
no setterinherited
consumeTapEvents bool
Returns true if this Controller will use its own onTap handler to consume events.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
infoWindow → InfoWindow?
Returns the gmaps.InfoWindow associated to the marker.
no setterinherited
infoWindowShown bool
Returns true if the gmaps.InfoWindow associated to this marker is being shown.
no setterinherited
marker → AdvancedMarkerElement?
Returns the marker associated to this controller.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMarkerListener({required AdvancedMarkerElement marker, required LatLngCallback? onDragStart, required LatLngCallback? onDrag, required LatLngCallback? onDragEnd, required VoidCallback? onTap}) → void
Initializes the listener for the wrapped marker object.
override
hideInfoWindow() → void
Hide the associated gmaps.InfoWindow.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
Disposes of the currently wrapped marker object.
override
setMap(Map map) → void
Sets the map of the wrapped marker object.
override
showInfoWindow() → void
Show the associated gmaps.InfoWindow.
override
toString() String
A string representation of this object.
inherited
update(AdvancedMarkerElementOptions options, {HTMLElement? newInfoWindowContent}) → void
Updates the options of the wrapped marker object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited