GroundOverlayController class

This wraps a GroundOverlay in a gmaps.MapType.

Constructors

GroundOverlayController({required GroundOverlay groundOverlay, required VoidCallback onTap})
Creates a GroundOverlayController that wraps a gmaps.GroundOverlay object.

Properties

groundOverlay → GroundOverlay?
The GroundOverlay providing data for this controller.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
Removes the GroundOverlay from the map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited