removeGroundOverlays method
Removes the ground overlays associated with the given GroundOverlayIds.
Implementation
void removeGroundOverlays(Set<GroundOverlayId> groundOverlayIds) {
groundOverlayIds.forEach(_removeGroundOverlay);
}
Removes the ground overlays associated with the given GroundOverlayIds.
void removeGroundOverlays(Set<GroundOverlayId> groundOverlayIds) {
groundOverlayIds.forEach(_removeGroundOverlay);
}