LegacyMarkersController class

A MarkersController for the legacy gmaps.Marker class.

Inheritance

Constructors

LegacyMarkersController({required StreamController<MapEvent<Object?>> stream, required ClusterManagersController<Marker> clusterManagersController})
Initialize the markers controller for the legacy gmaps.Marker class.

Properties

googleMap ↔ Map
The GMap instance that this controller operates on.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
mapId int
The map ID for events.
getter/setter pairinherited
markers Map<MarkerId, MarkerController<Marker, MarkerOptions>>
Returns the cache of MarkerControllers. Test only.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMarkers(Set<Marker> markersToAdd) Future<void>
Adds a set of Marker objects to the cache.
inherited
bindToMap(int mapId, Map googleMap) → void
Binds a mapId and the gmaps.Map instance to this controller.
inherited
changeMarkers(Set<Marker> markersToChange) Future<void>
Updates a set of Marker objects with new options.
inherited
createMarkerController(Marker marker, MarkerOptions markerOptions, InfoWindow? gmInfoWindow) Future<LegacyMarkerController>
Creates a MarkerController for the given marker.
override
hideMarkerInfoWindow(MarkerId markerId) → void
Hides the InfoWindow of a MarkerId.
inherited
isInfoWindowShown(MarkerId markerId) bool
Returns whether or not the InfoWindow of a MarkerId is shown.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMarkers(Set<MarkerId> markerIdsToRemove) → void
Removes a set of MarkerIds from the cache.
inherited
showMarkerInfoWindow(MarkerId markerId) → void
Shows the InfoWindow of a MarkerId.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited