MarkersController<T extends Object, O> class abstract

This class manages a set of MarkerControllers associated to a GoogleMapController.

Type parameters:

  • T - The marker type (e.g., gmaps.Marker or gmaps.AdvancedMarkerElement)
  • O - The options type used to configure the marker (e.g., gmaps.MarkerOptions or gmaps.AdvancedMarkerElementOptions)

T must extend JSObject. It's not specified in code because our mocking framework does not support mocking JSObjects.

Implementers

Constructors

MarkersController({required StreamController<MapEvent<Object?>> stream, required ClusterManagersController<T> clusterManagersController})
Initialize the cache. The StreamController comes from the GoogleMapController, and is shared with other controllers.

Properties

googleMap ↔ Map
The GMap instance that this controller operates on.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
mapId int
The map ID for events.
getter/setter pairinherited
markers Map<MarkerId, MarkerController<T, O>>
Returns the cache of MarkerControllers. Test only.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMarkers(Set<Marker> markersToAdd) Future<void>
Adds a set of Marker objects to the cache.
bindToMap(int mapId, Map googleMap) → void
Binds a mapId and the gmaps.Map instance to this controller.
inherited
changeMarkers(Set<Marker> markersToChange) Future<void>
Updates a set of Marker objects with new options.
createMarkerController(Marker marker, O markerOptions, InfoWindow? gmInfoWindow) Future<MarkerController<T, O>>
Creates a MarkerController for the given marker.
hideMarkerInfoWindow(MarkerId markerId) → void
Hides the InfoWindow of a MarkerId.
isInfoWindowShown(MarkerId markerId) bool
Returns whether or not the InfoWindow of a MarkerId is shown.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMarkers(Set<MarkerId> markerIdsToRemove) → void
Removes a set of MarkerIds from the cache.
showMarkerInfoWindow(MarkerId markerId) → void
Shows the InfoWindow of a MarkerId.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited