DebugCreateMapFunction typedef
Type used when passing an override to the _createMap function.
Implementation
@visibleForTesting
typedef DebugCreateMapFunction =
gmaps.Map Function(web.HTMLElement div, gmaps.MapOptions options);
Type used when passing an override to the _createMap function.
@visibleForTesting
typedef DebugCreateMapFunction =
gmaps.Map Function(web.HTMLElement div, gmaps.MapOptions options);