GroundOverlaysController class
This class manages all the GroundOverlayControllers associated to a GoogleMapController.
Constructors
-
GroundOverlaysController({required StreamController<
MapEvent< stream})Object?> > - Creates a new GroundOverlaysController instance.
Properties
- googleMap ↔ Map
-
The GMap instance that this controller operates on.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapId ↔ int
-
The map ID for events.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addGroundOverlays(
Set< GroundOverlay> groundOverlaysToAdd) → void -
Adds new
GroundOverlays to this controller. -
bindToMap(
int mapId, Map googleMap) → void -
Binds a
mapIdand thegmaps.Mapinstance to this controller.inherited -
changeGroundOverlays(
Set< GroundOverlay> groundOverlays) → void -
Updates
GroundOverlays with new options. -
getGroundOverlay(
GroundOverlayId groundOverlayId) → GroundOverlay? -
Returns the
GroundOverlaywith the givenGroundOverlayId. Only used for testing. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeGroundOverlays(
Set< GroundOverlayId> groundOverlayIds) → void -
Removes the ground overlays associated with the given
GroundOverlayIds. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited