HeatmapsController class
This class manages all the HeatmapControllers associated to a GoogleMapController.
Constructors
- HeatmapsController()
- Initialize the cache
Properties
- googleMap ↔ Map
-
The GMap instance that this controller operates on.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
heatmaps
→ Map<
HeatmapId, HeatmapController> -
Returns the cache of HeatmapControllers. Test only.
no setter
- mapId ↔ int
-
The map ID for events.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addHeatmaps(
Set< Heatmap> heatmapsToAdd) → void -
Adds a set of
Heatmapobjects to the cache. -
bindToMap(
int mapId, Map googleMap) → void -
Binds a
mapIdand thegmaps.Mapinstance to this controller.inherited -
changeHeatmaps(
Set< Heatmap> heatmapsToChange) → void -
Updates a set of
Heatmapobjects with new options. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeHeatmaps(
Set< HeatmapId> heatmapIdsToRemove) → void -
Removes a set of
HeatmapIds from the cache. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited